%global shortname da

Name:           devassistant
Version:        0.9.3
Release:        1%{?dist}
Summary:        DevAssistant - Making life easier for developers

License:        GPLv2+ and CC-BY-SA
URL:            https://github.com/bkabrda/devassistant
Source0:        https://pypi.python.org/packages/source/d/%{name}/%{name}-%{version}.tar.gz
# to get desktop and appdata file:
# git clone https://github.com/bkabrda/devassistant.git && cd devassistant
# git checkout v0.9.2
# # devassistant.desktop, appdata/devassistant.appdata.xml
Source1:        %{name}.desktop
Source2:        %{name}.appdata.xml

Patch0:         devassistant-0.6.0-alter-paths-for-fedora.patch

BuildArch:      noarch

BuildRequires:  desktop-file-utils
BuildRequires:  pytest
BuildRequires:  python2-devel
BuildRequires:  python-flexmock
BuildRequires:  python-jinja2
BuildRequires:  python-progress
BuildRequires:  python-setuptools
BuildRequires:  python-six

BuildRequires:  PyYAML

# it seems that other packages using bash-completion don't depend
# on it and rather just own the directory, so we will do the same
Requires:       git
# needed to create ssh key for GitHub access, not necessarily installed by default everywhere
Requires:       openssh-askpass
Requires:       polkit
Requires:       pygobject3
Requires:       python-jinja2
Requires:       python-progress
Requires:       python-PyGithub
Requires:       python-setuptools
Requires:       python-six
Requires:       PyYAML

%global __requires_exclude ^\(/usr/bin/php\|/usr/bin/perl\|perl\\(\)

%description
DevAssistant can help you with creating and setting up basic projects
in various languages, installing dependencies, setting up environmens,
working with source control, etc.

%prep
%setup -q -n %{name}-%{version}
# remove bundled egg-info
rm -rf %{name}.egg-info

cp %{SOURCE1} .
sed -i '/Version/d' %{name}.desktop

%build
%{__python} setup.py build

%install
%{__python} setup.py install --skip-build --root %{buildroot}

# manpages
mkdir -p %{buildroot}%{_mandir}/man1
install -p -m 644 manpages/%{shortname}.1 %{buildroot}%{_mandir}/man1
install -p -m 644 manpages/%{shortname}-gui.1 %{buildroot}%{_mandir}/man1
install -p -m 644 manpages/%{name}.1 %{buildroot}%{_mandir}/man1
install -p -m 644 manpages/%{name}-gui.1 %{buildroot}%{_mandir}/man1
# bash completion script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -p -m 644 %{shortname}.bash %{buildroot}%{_sysconfdir}/bash_completion.d/
# icons
for SIZE in 16x16 22x22 24x24 32x32 48x48 256x256; do
    mkdir -p %{buildroot}%{_datadir}/icons/hicolor/$SIZE/apps
    install -p -m 644 icons/hicolor/$SIZE/%{name}.png %{buildroot}%{_datadir}/icons/hicolor/$SIZE/apps/%{name}.png

    mkdir -p %{buildroot}%{_datadir}/icons/HighContrast/$SIZE/apps
    install -p -m 644 icons/HighContrast/$SIZE/%{name}.png %{buildroot}%{_datadir}/icons/HighContrast/$SIZE/apps/%{name}.png
done

## move data (assistants, snippets, templates) into %%{_datadir}
# first, do the alterations to paths in devassistant
pushd %{buildroot}%{python_sitelib}
patch -p1 < %{PATCH0} -F 3
sed -i 's|_DATADIR_DEVASSISTANT|%{_datadir}/%{name}|' devassistant/settings.py
popd
# now actually move the stuff
mv %{buildroot}%{python_sitelib}/%{name}/data %{buildroot}%{_datadir}/%{name}
# remove git subproject files
rm -rf %{buildroot}%{_datadir}/%{name}/.git*

# desktop and appdata
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{name}.desktop
mkdir -p %{buildroot}/%{_datadir}/appdata
cp -a %{SOURCE2} %{buildroot}/%{_datadir}/appdata

# polkit
mkdir -p %{buildroot}%{_datadir}/polkit-1/actions/
install -p -m 644 polkit/devassistant_auth.policy %{buildroot}%{_datadir}/polkit-1/actions/
mkdir -p %{buildroot}%{_libexecdir}
install -p -m 755 polkit/da_auth %{buildroot}%{_libexecdir}

%check
%{__python} setup.py test -t py.test

%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
/bin/touch --no-create %{_datadir}/icons/HighContrast &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /bin/touch --no-create %{_datadir}/icons/HighContrast &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/HighContrast &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files
%doc README.rst LICENSE
%{_bindir}/%{shortname}
%{_bindir}/%{shortname}-gui
%{_bindir}/%{name}
%{_bindir}/%{name}-gui
%{_datadir}/%{name}
%{_mandir}/man1/%{shortname}.1.gz
%{_mandir}/man1/%{shortname}-gui.1.gz
%{_mandir}/man1/%{name}.1.gz
%{_mandir}/man1/%{name}-gui.1.gz
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/HighContrast/*/apps/%{name}.png
%{_datadir}/polkit-1/actions/%{name}_auth.policy
%{_libexecdir}/da_auth
%{_sysconfdir}/bash_completion.d/
%{python_sitelib}/%{name}
%{python_sitelib}/%{name}-%{version}-py?.?.egg-info

%changelog
* Thu Nov 13 2014 Tomas Radej <tradej@redhat.com> - 0.9.3-1
- Updated to newer upstream version

* Wed Nov 12 2014 Tomas Radej <tradej@redhat.com> - 0.9.2-8
- Incorporated upstream patch in the polkit policy

* Tue Nov 11 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-7
- Fix installation on "Generic" Fedora builds.
Resolves: rhbz#1162467

* Fri Oct 24 2014 Tomas Radej <tradej@redhat.com> - 0.9.2-6
- Backported custom polkit policy (bz#1156292)

* Wed Oct 08 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-5
- Fix issue in Django assistant when used with --venv and --py3

* Fri Oct 03 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-4
- One more fix for java assistants dependencies.

* Fri Oct 03 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-3
- Fix java assistants dependencies.

* Thu Oct 02 2014 Slavek Kabrda <bkabrda@redhat.com> - 0.9.2-2
- Add openssh-askpass dependency.

* Mon Sep 01 2014 Tomas Radej <tradej@redhat.com> - 0.9.2-1
- Updated to latest upstream version
- Added high contrast icon

* Mon Jun 23 2014 Tomas Radej <tradej@redhat.com> - 0.9.1-2
- Added forgotten changelog

* Mon Jun 23 2014 Tomas Radej <tradej@redhat.com> - 0.9.1-1
- Updated to latest upstream version

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Jun 03 2014 Tomas Radej <tradej@redhat.com> - 0.9.0-1
- Updated to latest upstream version

* Mon Apr 14 2014 Tomas Radej <tradej@redhat.com> - 0.8.0-3
- Added CC-BY-SA to License field because of appdata.xml

* Fri Feb 28 2014 Miro Hrončok <mhroncok@redhat.com> - 0.8.0-2
- Backport fix of GitHub errors.

* Wed Dec 04 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.8.0-1
- Update to 0.8.0.
- Don't create the /usr/local hierarchy, leave it up to users.

* Wed Oct 02 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.7.0-1
- Update to 0.7.0.

* Wed Aug 28 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.6.1-2
- Properly create and own the /usr/local hierarchy.

* Wed Aug 28 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.6.1-1
- Update to 0.6.1.
- Introduce gui, add its dependencies.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jul 26 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.5.0-1
- Update to 0.5.0.
- Regenerated patch0.

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 0.4.0-3
- Perl 5.18 rebuild

* Wed Jul 03 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.4.0-2
- Fix manpage typo, rhbz#980646.

* Mon Jul 01 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.4.0-1
- Update to 0.4.0.

* Wed May 15 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.3.1-1
- Update to 0.3.1.
- Remove no longer needed dependencies (jinja2, plumbum).

* Wed Mar 20 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.2.2-1
- Update to 0.2.2 because of minor bug in 0.2.1.

* Wed Mar 20 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.2.1-1
- Update to devassistant 0.2.1.
- Introduce bash completion script.

* Mon Mar 18 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.2.0-1
- Update to devassistant 0.2.0.
- Move assistants and snippets to %%{datadir}/%%{name}.
- Introduce manpage.

* Tue Mar 12 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.1.0-3
- Move templates to %%{_datadir}.

* Tue Mar 12 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.1.0-2
- Use BR: python2-devel instead of python-devel.

* Fri Mar 08 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 0.1.0-1
- Initial package.
